@@ -20,7 +20,7 @@
  *
  * Author: Josh MacDonald <jmacd@CS.Berkeley.EDU>
  *
- * $Id: xdmain.c 1.22.1.5 Fri, 29 Jun 2001 06:01:08 -0700 jmacd $
+ * $Id: xdmain.c 1.22.1.4 Sun, 24 Jun 2001 01:02:51 -0700 jmacd $
  */
 
 #include <stdio.h>
@@ -193,7 +193,7 @@ struct _XdFileHandle
 };
 
 /* $Format: "static const char xdelta_version[] = \"$ReleaseVersion$\"; " $ */
-static const char xdelta_version[] = "1.1.3"; 
+static const char xdelta_version[] = "1.1.2"; 
 
 typedef struct _Command Command;
 
@@ -637,7 +637,7 @@ file_gunzip (const char* name)
 
   if (nread < 0)
     {
-      xd_error ("gzread %s failed\n", name);
+      xd_error ("gzread %s failed: %s\n", name, g_strerror (errno));
       return NULL;
     }
 
